==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d4/d3d/framerate__gui_8cpp.js <==
var framerate__gui_8cpp =
[
    [ "PerformanceData", "dd/da3/structanonymous__namespace_02framerate__gui_8cpp_03_1_1PerformanceData.html", "dd/da3/structanonymous__namespace_02framerate__gui_8cpp_03_1_1PerformanceData" ],
    [ "FramerateWindow", "d7/d2d/structFramerateWindow.html", "d7/d2d/structFramerateWindow" ],
    [ "CachedDecimal", "da/d5a/structFramerateWindow_1_1CachedDecimal.html", "da/d5a/structFramerateWindow_1_1CachedDecimal" ],
    [ "FrametimeGraphWindow", "da/d32/structFrametimeGraphWindow.html", "da/d32/structFrametimeGraphWindow" ],
    [ "ConPrintFramerate", "d4/d3d/framerate__gui_8cpp.html#ab193f179a10e380913253f264e8b95c5", null ],
    [ "GetPerformanceTimer", "d4/d3d/framerate__gui_8cpp.html#a4b6634e02efe12b49be95dbdd024c4f4", null ],
    [ "ShowFramerateWindow", "d4/d3d/framerate__gui_8cpp.html#a3572727f0e8cd9afb76420bbee9db6b6", null ],
    [ "ShowFrametimeGraphWindow", "d4/d3d/framerate__gui_8cpp.html#a5fa940526cbe0c7647038a2860843fcd", null ],
    [ "_framerate_display_desc", "d4/d3d/framerate__gui_8cpp.html#aa6a7ae8c1887fe7b407582fef750d3d8", null ],
    [ "_framerate_window_widgets", "d4/d3d/framerate__gui_8cpp.html#aab744ddea1f86dba632a4f90be49b718", null ],
    [ "_frametime_graph_window_desc", "d4/d3d/framerate__gui_8cpp.html#a23f7ee1c99ba6ec0d2270fab6ae323b6", null ],
    [ "_frametime_graph_window_widgets", "d4/d3d/framerate__gui_8cpp.html#abe78b40d2e3370223c3cfd516d7e5db3", null ],
    [ "_pf_data", "d4/d3d/framerate__gui_8cpp.html#aeb28fbc95809039422b4c406a71aea1b", null ],
    [ "GL_RATE", "d4/d3d/framerate__gui_8cpp.html#a3e0be6ebec7de0d21b878401dae4461c", null ],
    [ "NUM_FRAMERATE_POINTS", "d4/d3d/framerate__gui_8cpp.html#a879276018c8234553690619a6bf8b55c", null ],
    [ "TIMESTAMP_PRECISION", "d4/d3d/framerate__gui_8cpp.html#a3b41519730abb18df1a011a4fc8561b3", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d4/d3d/framerate__gui_8cpp.js <==
var framerate__gui_8cpp =
[
    [ "PerformanceData", "dd/da3/structanonymous__namespace_02framerate__gui_8cpp_03_1_1PerformanceData.html", "dd/da3/structanonymous__namespace_02framerate__gui_8cpp_03_1_1PerformanceData" ],
    [ "FramerateWindow", "d7/d2d/structFramerateWindow.html", "d7/d2d/structFramerateWindow" ],
    [ "CachedDecimal", "da/d5a/structFramerateWindow_1_1CachedDecimal.html", "da/d5a/structFramerateWindow_1_1CachedDecimal" ],
    [ "FrametimeGraphWindow", "da/d32/structFrametimeGraphWindow.html", "da/d32/structFrametimeGraphWindow" ],
    [ "ConPrintFramerate", "d4/d3d/framerate__gui_8cpp.html#ab193f179a10e380913253f264e8b95c5", null ],
    [ "GetAIName", "d4/d3d/framerate__gui_8cpp.html#a3ecf00ec624557d43df4d289df274cd3", null ],
    [ "GetPerformanceTimer", "d4/d3d/framerate__gui_8cpp.html#a4b6634e02efe12b49be95dbdd024c4f4", null ],
    [ "ShowFramerateWindow", "d4/d3d/framerate__gui_8cpp.html#a3572727f0e8cd9afb76420bbee9db6b6", null ],
    [ "ShowFrametimeGraphWindow", "d4/d3d/framerate__gui_8cpp.html#a5fa940526cbe0c7647038a2860843fcd", null ],
    [ "_framerate_display_desc", "d4/d3d/framerate__gui_8cpp.html#aab5eb3a51376b4bc08545747a79414c5", null ],
    [ "_framerate_window_widgets", "d4/d3d/framerate__gui_8cpp.html#aab744ddea1f86dba632a4f90be49b718", null ],
    [ "_frametime_graph_window_desc", "d4/d3d/framerate__gui_8cpp.html#a23f7ee1c99ba6ec0d2270fab6ae323b6", null ],
    [ "_frametime_graph_window_widgets", "d4/d3d/framerate__gui_8cpp.html#abe78b40d2e3370223c3cfd516d7e5db3", null ],
    [ "_pf_data", "d4/d3d/framerate__gui_8cpp.html#aeb28fbc95809039422b4c406a71aea1b", null ],
    [ "DISPLAY_ORDER_PFE", "d4/d3d/framerate__gui_8cpp.html#a6bcd30d473e2b9866793efc1ef82b2dc", null ],
    [ "GL_RATE", "d4/d3d/framerate__gui_8cpp.html#a3e0be6ebec7de0d21b878401dae4461c", null ],
    [ "NUM_FRAMERATE_POINTS", "d4/d3d/framerate__gui_8cpp.html#a879276018c8234553690619a6bf8b55c", null ],
    [ "TIMESTAMP_PRECISION", "d4/d3d/framerate__gui_8cpp.html#a3b41519730abb18df1a011a4fc8561b3", null ]
];
